@@ -46,12 +46,12 @@ test_that(
                          scale=scale, addcovar=as.matrix(fake_nei$pheno$grouping),
                          grouping=fake_nei$pheno$grouping, response="binary", model="lm")
 
-    expect_true(min(-log10(gwas_lmm[,3]))>=0)
+    expect_true(min(-log10(gwas_lmm[,3]),na.rm=TRUE)>=0)
 
-    expect_true(min(-log10(gwas_glmm[,3]))>=0)
+    expect_true(min(-log10(gwas_glmm[,3]),na.rm=TRUE)>=0)
 
-    expect_true(min(-log10(gwas_lm[,3]))>=0)
+    expect_true(min(-log10(gwas_lm[,3]),na.rm=TRUE)>=0)
 
-    expect_true(min(-log10(gwas_glm[,3]))>=0)
+    expect_true(min(-log10(gwas_glm[,3]),na.rm=TRUE)>=0)
   }
 )
